(* $Id: findlib.mli,v 1.2 1999/06/20 19:26:22 gerd Exp $
 * ----------------------------------------------------------------------
 *
 *)

val package_directory : string -> string
  (* get the absolute path of the directory where the given package is
   * stored.
   * raises Not_found if the package could not be found.
   *)


val package_property : string list -> string -> string -> string
  (* package_property predlist pkg propname:
   * looks up the property 'propname' of package 'pkg' under the assumption
   * that the predicates in 'predlist' are true.
   * raises Not_found if the package or the property could not be found.
   *
   * EXAMPLES:
   * - package_property [] "p" "requires":
   *   get the value of the 'requires' clause of package 'p'
   * - package_property [ "mt"; "byte" ] "p" "archive":
   *   get the value of the 'archive' property of package 'p' for multi-
   *   threaded bytecode applications.
   *)

val package_ancestors : string list -> string -> string list
  (* package_ancestors predlist pkg:
   * determines the direct ancestors of package 'pkg' under the assumption
   * that the predicates in 'predlist' are true, i.e. the names of the
   * packages required by 'pkg'.
   * The returned list is unsorted.
   * raises Not_found if the package 'pkg' could not be found.
   * fails if one of the ancestors could not be found.
   *)

val package_deep_ancestors : string list -> string list -> string list
  (* package_deep_ancestors predlist pkglist:
   * determines the list of direct or indirect ancestors of the packages
   * named in 'pkglist' under the assumption that the predicates in 'predlist' 
   * are true. 
   * The returned list is topologically sorted: The first element is the
   * deepest ancestor; the last element is one of 'pkglist'.
   * raises Not_found if one of the packages in 'pkglist' could not be found.
   * fails if one of the ancestors could not be found.
   * fails if there is a cyclic dependency.
   *)


val default_location : unit -> string
  (* Get the system-wide default location for packages *)


(* ======================================================================
 * History:
 *
 * $Log: findlib.mli,v $
 * Revision 1.2  1999/06/20 19:26:22  gerd
 * 	Major change: Added support for META files. In META files, knowlege
 * about compilation options, and dependencies on other packages can be stored.
 * The "ocamlfind query" subcommand has been extended in order to have a
 * direct interface for that. "ocamlfind ocamlc/ocamlopt/ocamlmktop/ocamlcp"
 * subcommands have been added to simplify the invocation of the compiler.
 *
 * Revision 1.1  1999/03/26 00:02:47  gerd
 * 	Initial release.
 *
 *
 *)
